#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-better-errors
version:              0.9.1.0
visibility:           public
id:                   aeson-better-errors-0.9.1.0-LSak8f9kkLmGssW3MUNu2j
key:                  aeson-better-errors-0.9.1.0-LSak8f9kkLmGssW3MUNu2j
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/aeson-better-errors
synopsis:             Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.

category:             Text, Web, JSON
abi:                  162a69d415eb7b0859d859dbf77b5a31
exposed:              True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal

hidden-modules:       Data.Aeson.BetterErrors.Utils
import-dirs:          /usr/lib/ghc-8.10.5/site-local/aeson-better-errors-0.9.1.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/aeson-better-errors-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/aeson-better-errors-0.9.1.0

hs-libraries:         HSaeson-better-errors-0.9.1.0-LSak8f9kkLmGssW3MUNu2j
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ base-4.14.2.0
    bytestring-0.10.12.0 dlist-1.0-2pxhAw6JY91eMk6tw7lC2 mtl-2.2.2
    scientific-0.3.7.0-Fi0gRGhsiJ35wgbCjOXuHX text-1.2.4.1
    transformers-0.5.6.2
    transformers-compat-0.6.6-8xD7tdhdla21VYsnm1hEvk
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp
    void-0.7.3-72JC1ZJs2iULdltk7dpkuA

haddock-interfaces:
    /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock

haddock-html:         /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

